@@ -21,6 +21,7 @@
 #include <QTest>
 #include <QTimer>
 #include <QDir>
+#include <QTemporaryDir>
 #include <QTemporaryFile>
 #include <QFileDialog>
 #include <KFileWidget>
@@ -42,7 +43,6 @@ private Q_SLOTS:
 
     void init()
     {
-        qDebug() << QDateTime::currentDateTime() << "INIT";
     }
 
     void cleanupTestCase()
@@ -84,7 +84,7 @@ private Q_SLOTS:
 
     void testSelectUrl()
     {
-        QTemporaryFile tempFile(QDir::tempPath()+"/kfiledialogtest_XXXXXX");
+        QTemporaryFile tempFile(m_tempDir.path()+"/kfiledialogtest_XXXXXX");
         tempFile.setAutoRemove(true);
         tempFile.open();
         QString tempName = tempFile.fileName();
@@ -103,7 +103,7 @@ private Q_SLOTS:
     void testGetSaveFileUrl()
     {
         QObject lambdaGuard;
-        QTemporaryFile tempFile(QDir::tempPath()+"/kfiledialogtest_XXXXXX");
+        QTemporaryFile tempFile(m_tempDir.path()+"/kfiledialogtest_XXXXXX");
         tempFile.open();
         const QString tempName = tempFile.fileName();
         const QUrl url = QUrl::fromLocalFile(tempName);
@@ -263,84 +263,47 @@ private Q_SLOTS:
         QFETCH(bool, qtOverwriteOption);
         QFETCH(bool, messageBoxExpected);
         
-        qDebug() << QDateTime::currentDateTime() << "1";
-        QTemporaryFile tempFile(QDir::tempPath()+"/kfiledialogtest_XXXXXX");
-        qDebug() << QDateTime::currentDateTime() << "1.1";
+        QTemporaryFile tempFile(m_tempDir.path()+"/kfiledialogtest_XXXXXX");
         tempFile.setAutoRemove(true);
-        qDebug() << QDateTime::currentDateTime() << "1.2";
         tempFile.open();
-        qDebug() << QDateTime::currentDateTime() << "1.3";
         QString tempName = tempFile.fileName();
-        qDebug() << QDateTime::currentDateTime() << "1.4";
         tempFile.close();
-        qDebug() << QDateTime::currentDateTime() << "1.5";
         int idx = tempName.lastIndexOf('/');
         
-        qDebug() << QDateTime::currentDateTime() << "2";
-
         QFileDialog dialog;
-        qDebug() << QDateTime::currentDateTime() << "2.1";
         dialog.setAcceptMode(QFileDialog::AcceptSave);
-        qDebug() << QDateTime::currentDateTime() << "2.2";
         if (qtOverwriteOption) dialog.setOption(QFileDialog::DontConfirmOverwrite);
-        qDebug() << QDateTime::currentDateTime() << "2.3";
         dialog.setDirectory(tempName.left(idx+1));
-        qDebug() << QDateTime::currentDateTime() << "2.4";
         dialog.selectFile(tempName.mid(idx+1));
-        qDebug() << QDateTime::currentDateTime() << "2.5";
         dialog.open();
         
-        qDebug() << QDateTime::currentDateTime() << "3";
-
         KFileWidget *fw = findFileWidget();
-        qDebug() << QDateTime::currentDateTime() << "3.1";
         QVERIFY(fw);
-        qDebug() << QDateTime::currentDateTime() << "3.2";
         QTest::qWaitForWindowExposed(fw->window());
-        qDebug() << QDateTime::currentDateTime() << "3.3";
         QCOMPARE(fw->isVisible(), true);
         
-        qDebug() << QDateTime::currentDateTime() << "4";
+        bool timerRun = false;
 
-        messageBoxSeen = false;
-        checkMessageBoxRun = false;
-        qDebug() << QDateTime::currentDateTime() << "4.1";
-        QTimer::singleShot(3500, this, SLOT(checkMessageBox()));
-        qDebug() << QDateTime::currentDateTime() << "4.2";
+        QTimer::singleShot(3500, this, [&] {
+            timerRun = true;
+            QDialog *msgbox = findMessageBox();
+            if (msgbox)
+            {
+                QTest::qWaitForWindowExposed(msgbox);
+                QCOMPARE(msgbox->isVisible(), true);
+                msgbox->close();
+                QVERIFY(messageBoxExpected);
+            } else {
+                QVERIFY(!messageBoxExpected);
+            }
+        });
         fw->slotOk();
         
-        qDebug() << QDateTime::currentDateTime() << "5";
-
-        fw->slotCancel();
-        qDebug() << QDateTime::currentDateTime() << "5.1";
-        QTRY_VERIFY(checkMessageBoxRun);
-        QVERIFY(messageBoxSeen == messageBoxExpected);
-        
-        qDebug() << QDateTime::currentDateTime() << "6";
-    }
-
-protected Q_SLOTS:
-    void checkMessageBox()
-    {
-        checkMessageBoxRun = true;
-        qDebug() << QDateTime::currentDateTime() << "A";
-        QDialog *msgbox = findMessageBox();
-        qDebug() << QDateTime::currentDateTime() << "B";
-        if (!msgbox) return;
-        qDebug() << QDateTime::currentDateTime() << "C";
-        QTest::qWaitForWindowExposed(msgbox);
-        qDebug() << QDateTime::currentDateTime() << "D";
-        QCOMPARE(msgbox->isVisible(), true);
-        qDebug() << QDateTime::currentDateTime() << "E";
-        messageBoxSeen = true;
-        qDebug() << QDateTime::currentDateTime() << "F";
-        msgbox->close();
-        qDebug() << QDateTime::currentDateTime() << "G";
+        QTRY_VERIFY(timerRun);
     }
 
 private:
-    bool messageBoxSeen;
-    bool checkMessageBoxRun;
+    QTemporaryDir m_tempDir;
 
     static QString fileViewToString(KFile::FileView fv)
     {
